<?php
/** Gitlab Issue List Script
*
* Simple script to generate an simple HTML listing of Gitlab Issues using the public API
*
*
* @copyright (C) 2021 B Tasker (http://www.bentasker.co.uk). All rights reserved
* @license GNU GPL V3 - See LICENSE
*
* @version 0.1
*
*/

defined('listpage') or die;
?>

<html>
<head>
<meta name="viewport" content="width=device-width, initial-scale=1">
<title><?php echo htmlspecialchars($issues['project']->name_with_namespace); ?>: Label <?php echo htmlspecialchars($issues['label']); ?></title>

<meta name="description" content="<?php echo htmlentities(utf8_encode($issues['project']->description)); ?> : Label <?php echo htmlspecialchars($issues['label']); ?>" />

<link rel="stylesheet" type="text/css" href="<?php echo GILSUtils::qs2sef("css=labels&projpath={$issues['project']->path_with_namespace}",".css");?>" />

<?php require 'head-includes.php'; ?>
</head>
<body itemscope itemtype="http://schema.org/CollectionPage">



<!--sphider_noindex-->

<hr />
<?php if ($issues['project']->avatar_url): ?>
<img 
    class='projavatar-small' src='<?php echo GILSUtils::getAvatarUrl($issues['project']->avatar_url); ?>' 
    alt="project <?php echo htmlspecialchars($issues['project']->name_with_namespace); ?> avatar"
    >
<?php endif; ?>
<h1 itemprop='name'><?php echo htmlspecialchars($issues['project']->name_with_namespace);?>: <?php echo htmlspecialchars($issues['project']->name) ?>: Label <?php echo htmlspecialchars($issues['label']); ?></h1>
<hr />
<ul itemprop="breadcrumb" class="breadcrumbs">
        <li><a href="/index.html">Projects</a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("proj={$issues['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($issues['project']->name_with_namespace);?></a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("proj={$issues['project']->path_with_namespace}");?>#labels">Labels</a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("label={$issues["label_obj"]->id}&projpath={$issues['project']->path_with_namespace}"); ?>"><span 
                       class="label labelid-<?php echo htmlspecialchars($issues["label_obj"]->id);?>"><?php echo htmlspecialchars($issues['label']); ?></span></a></li>
</ul>
<hr />


<div class='projdesc'>
    <a href="<?php echo GILSUtils::qs2sef("label={$issues["label_obj"]->id}&projpath={$issues['project']->path_with_namespace}"); ?>">
        <span class="label labelid-<?php echo htmlspecialchars($issues["label_obj"]->id);?>">
        <?php echo
                htmlspecialchars($issues['label']); ?></span>
    </a>
    <?php
        echo GILSUtils::markdownToHTML($issues['label_obj']->description);
    ?>
</div>

		

<h3>Timeline</h3>
<div class="lbltimeline">

<?php

$begin = new DateTime($issues['start']);
$end = new DateTime($issues['end']);
$dateinterval = new DateInterval('P1M');

//$daterange = new DatePeriod($begin, $dateinterval, $end);

$x = 0;
$date = $end;
$begin->sub($dateinterval);

while($date >= $begin){
    $key = $date->format('M-y');
    echo "<div class='lblrow'>\n";
    if ($x == 0){
        ?>
            <div class='lblleft hascontent'>
                    <a class="lbldatemobile" href="#<?php echo $key; ?>">
                        <span class="lbldate"><?php echo $date->format("M Y") ;?></span>
                    </a>
                    <div class="divd"></div>
                    
                    <?php if (array_key_exists($key, $issues["issues"])){
                        foreach ($issues["issues"][$key] as $issue){
                            ?>
                            <span class="lblissitem">
                                <a itemprop="url name" class="lblisslink" href='<?php echo GILSUtils::qs2sef("issue={$issue['gitlab_reference']}");?>'><?php echo htmlspecialchars("{$issue['short_reference']}"); ?></a> <?php echo htmlspecialchars("{$issue['title']} ({$issue['state']})"); ?>
                            </span>
                            <?php 
                        }
                    }
                    ?>
            </div>
            <div class='lblright'>
                <a name="<?php echo $key; ?>" class="lbldate" href="#<?php echo $key; ?>">
                    <span class="lbldate"><?php echo $date->format("t M Y") ;?></span>
                </a>
            </div>
        <?php
        $x = 1;
    }else{
        ?>
            <div class='lblleft'>
                <a name="<?php echo $key; ?>" class="lbldate" href="#<?php echo $key; ?>">
                    <span class="lbldate"><?php echo $date->format("t M Y") ;?></span>
                </a>
            </div>
            <div class='lblright hascontent'>
                    <a class="lbldatemobile" href="#<?php echo $key; ?>">
                        <span class="lbldate"><?php echo $date->format("M Y") ;?></span>
                    </a>
                    
                    <div class="divd"></div>
                    <?php if (array_key_exists($key, $issues["issues"])){
                        foreach ($issues["issues"][$key] as $issue){
                            ?>
                            <span class="lblissitem">
                                <a itemprop="url name" class="lblisslink" href='<?php echo GILSUtils::qs2sef("issue={$issue['gitlab_reference']}");?>'><?php echo htmlspecialchars("{$issue['short_reference']}"); ?></a><?php echo htmlspecialchars(" {$issue['title']} ({$issue['state']})"); ?>
                            </span>
                            
                            <?php
                        }
                    }
                    ?>

            </div>
        <?php
        $x = 0;
    }
    echo "</div>\n";
    
    // Subtract a month
    $date = $date->sub($dateinterval);
}


?>
</div>
</html>
